@@ -1,11 +1,11 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 1.37 2004/02/24 02:43:17 bkorb Exp $
+ *  $Id: agShell.c,v 4.7 2005/06/07 22:26:43 bkorb Exp $
  *  Manage a server shell process
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -20,8 +20,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 #ifndef SHELL_ENABLED
@@ -43,20 +43,26 @@
 /*
  *  Dual pipe opening of a child process
  */
-STATIC tpfPair serverPair = { NULL, NULL };
-STATIC pid_t   serverId   = NULLPROCESS;
-STATIC tpChar  pCurDir    = NULL;
-STATIC ag_bool errClose   = AG_FALSE;
+static tpfPair serverPair = { NULL, NULL };
+static pid_t   serverId   = NULLPROCESS;
+static tpChar  pCurDir    = NULL;
+static ag_bool errClose   = AG_FALSE;
 
 tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s\n";
 
 const char* pzLastCmd = NULL;
 
-STATIC void sigHandler( int signo );
-STATIC void serverSetup( void );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static void
+sigHandler( int signo );
+
+static void
+serverSetup( void );
+/* = = = END-STATIC-FORWARD = = = */
 
 
-EXPORT void
+LOCAL void
 closeServer( void )
 {
     if (serverId == NULLPROCESS)
@@ -80,7 +86,7 @@ closeServer( void )
 }
 
 
-STATIC void
+static void
 sigHandler( int signo )
 {
     fprintf( pfTrace, "Closing server:  %s signal (%d) received\n",
@@ -98,7 +104,7 @@ sigHandler( int signo )
 }
 
 
-STATIC void
+static void
 serverSetup( void )
 {
     struct sigaction  saNew;
@@ -133,30 +139,11 @@ serverSetup( void )
     errClose = AG_FALSE;
 
     {
-        static char zTrap[] =
-            /*
-             *  IF it is possible to put the base shell into POSIX/Bourne mode,
-             *  THEN do so...
-             */
-            "if test -n \"${ZSH_VERSION+set}\" "
-                "&& (emulate sh) >/dev/null 2>&1\n"
-            "then\n"
-            "  emulate sh\n"
-            "  NULLCMD=:\n"
-            "else if test -n \"${BASH_VERSION+set}\" "
-                  "&& (set -o posix) >/dev/null 2>&1\n"
-            "then\n"
-            "  set -o posix\n"
-            "fi ; fi\n"
-
-            "for f in 1 2 5 6 7 13 14\n"
-            "do trap \"echo trapped on $f >&2\" $f 2>/dev/null\n"
-            "done\n" "unalias cd 2>/dev/null >&2\n" "AG_pid=\000.........\n";
         static char* pzPid = NULL;
         char* pz;
-        pzLastCmd = zTrap;
+        pzLastCmd = zShellInit;
         if (pzPid == NULL)
-            pzPid = zTrap + strlen( zTrap );
+            pzPid = zShellInit + strlen(zShellInit);
         sprintf( pzPid, "%d\n", getpid() );
         fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzLastCmd, zShDone );
         (void)fflush( serverPair.pfWrite );
@@ -196,7 +183,7 @@ serverSetup( void )
  *  for the new process and, optionally, a pointer to a place
  *  to store the child's process id.
  */
-EXPORT int
+LOCAL int
 chainOpen( int       stdinFd,
            tCC**     ppArgs,
            pid_t*    pChild  )
@@ -353,7 +340,7 @@ chainOpen( int       stdinFd,
  *  process should write to "writeFd" and read from "readFd".
  *  The return value is the process id of the created process.
  */
-EXPORT pid_t
+LOCAL pid_t
 openServer( tFdPair* pPair, tCC** ppArgs )
 {
     pid_t     chId;
@@ -380,7 +367,7 @@ openServer( tFdPair* pPair, tCC** ppArgs )
  *  Identical to "openServer()", except that the "fd"'s are "fdopen(3)"-ed
  *  into file pointers instead.
  */
-EXPORT pid_t
+LOCAL pid_t
 openServerFP( tpfPair* pfPair, tCC** ppArgs )
 {
     tFdPair   fdPair;
@@ -389,8 +376,8 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
     if (chId == NOPROCESS)
         return chId;
 
-    pfPair->pfRead  = fdopen( fdPair.readFd,  "r" FOPEN_TEXT_FLAG );
-    pfPair->pfWrite = fdopen( fdPair.writeFd, "w" FOPEN_TEXT_FLAG );
+    pfPair->pfRead  = fdopen( fdPair.readFd,  "r" FOPEN_BINARY_FLAG );
+    pfPair->pfWrite = fdopen( fdPair.writeFd, "w" FOPEN_BINARY_FLAG );
     return chId;
 }
 #endif /* SHELL_ENABLED */
@@ -404,7 +391,7 @@ openServerFP( tpfPair* pfPair, tCC** ppArgs )
  *  The read data are stored in a malloc-ed string that is truncated
  *  to size at the end.  Input is assumed to be an ASCII string.
  */
-EXPORT char*
+LOCAL char*
 loadData( FILE* fp )
 {
     char*   pzText;
@@ -489,7 +476,7 @@ loadData( FILE* fp )
  *  If one of the commands we send to it takes too long or it dies,
  *  we will shoot it and restart one later.
  */
-EXPORT char*
+LOCAL char*
 runShell( const char*  pzCmd )
 {
     tSCC zCmdFail[] = "CLOSING SHELL SERVER - command failure:\n\t%s\n";
