@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Friday December 31, 2004 at 08:18:56 PM PST
+ *  It has been AutoGen-ed  Thursday July 28, 2005 at 04:19:15 PM PDT
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2004  by  Bruce Korb
+ *  Copyright (c) 2001-2005  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -200,7 +200,10 @@ cgi_run_fsm(
 {
     te_cgi_state cgi_state = CGI_ST_INIT;
     te_cgi_event trans_evt;
-    te_cgi_state nxtSt, firstNext;
+#ifdef DEBUG
+    te_cgi_state firstNext;
+#endif
+    te_cgi_state nxtSt;
     te_cgi_trans trans;
 
     while (cgi_state < CGI_ST_INVALID) {
@@ -238,8 +241,12 @@ cgi_run_fsm(
             nxtSt = CGI_ST_INVALID;
             trans = CGI_TR_INVALID;
         } else {
-            const t_cgi_transition* pTT = cgi_trans_table[ cgi_state ] + trans_evt;
-            nxtSt = firstNext = pTT->next_state;
+            const t_cgi_transition* pTT =
+            cgi_trans_table[ cgi_state ] + trans_evt;
+#ifdef DEBUG
+            firstNext = /* next line */
+#endif
+            nxtSt = pTT->next_state;
             trans = pTT->transition;
         }
 
