@@ -1,11 +1,11 @@
 /*
- *  $Id: defFind.c,v 1.26 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: defFind.c,v 4.4 2005/06/07 22:26:43 bkorb Exp $
  *
  *  This module locates definitions.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -20,8 +20,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 struct defEntryList {
@@ -36,14 +36,32 @@ tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
 
 tSC zDefinitionName[ MAXPATHLEN ];
 
-STATIC tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
+static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
 #define ILLFORMEDNAME() \
     AG_ABEND( aprf( zNameRef, zDefinitionName, \
               pCurTemplate->pzFileName, pCurMacro->lineNo ));
 
 
-STATIC tDefEntry*
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tDefEntry*
+findEntryByIndex( tDefEntry* pE, char* pzScan );
+
+static void
+addResult( tDefEntry* pDE, tDefEntryList* pDEL );
+
+static size_t
+badName( char* pzD, const char* pzS, size_t srcLen );
+
+static tDefEntry*
+defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed );
+
+static tDefEntry**
+entryListSearch( char* pzName, tDefCtx* pDefCtx );
+/* = = = END-STATIC-FORWARD = = = */
+
+static tDefEntry*
 findEntryByIndex( tDefEntry* pE, char* pzScan )
 {
     int  idx;
@@ -163,7 +181,7 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
 }
 
 
-STATIC size_t
+static size_t
 badName( char* pzD, const char* pzS, size_t srcLen )
 {
     memcpy( (void*)pzD, (void*)pzS, srcLen );
@@ -184,7 +202,7 @@ badName( char* pzD, const char* pzS, size_t srcLen )
  *      (always skipping white space).
  *  We start in CN_START.
  */
-EXPORT int
+LOCAL int
 canonicalizeName( char* pzD, const char* pzS, int srcLen )
 {
     typedef enum {
@@ -368,7 +386,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
  *  the element has been indexed (so the caller will not try
  *  to traverse the list of twins).
  */
-STATIC tDefEntry*
+static tDefEntry*
 defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
 {
     char*        pcBrace;
@@ -534,7 +552,7 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
 }
 
 
-EXPORT tDefEntry*
+LOCAL tDefEntry*
 findDefEntry( char* pzName, ag_bool* pIsIndexed )
 {
     return defEntrySearch( pzName, &currDefCtx, pIsIndexed );
@@ -550,7 +568,7 @@ findDefEntry( char* pzName, ag_bool* pIsIndexed )
  *  indicator saying if the element has been indexed (so the caller will
  *  not try to traverse the list of twins).
  */
-STATIC tDefEntry**
+static tDefEntry**
 entryListSearch( char* pzName, tDefCtx* pDefCtx )
 {
     static tDefEntryList defList = { 0, 0, NULL, 0 };
@@ -725,7 +743,7 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
 }
 
 
-EXPORT tDefEntry**
+LOCAL tDefEntry**
 findEntryList( char* pzName )
 {
     return entryListSearch( pzName, &currDefCtx );
