@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defLex.c,v 4.5 2005/02/14 17:03:51 bkorb Exp $
+ *  $Id: defLex.c,v 4.7 2005/07/27 17:26:31 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
@@ -21,8 +21,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 tSCC zErrMsg[] = "%s Error:  %s in %s on line %d\n";
 
@@ -544,7 +544,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
-                *pRetVal = aKeywordTkn[ kw_ix ];
+                *pRetVal = (te_dp_event)aKeywordTkn[ kw_ix ];
                 break;
             }
         } while (++kw_ix < KEYWORD_CT);
