@@ -1,15 +1,16 @@
 
 /*
- *  Time-stamp:      "2004-08-30 19:09:50 bkorb"
+ *  Time-stamp:      "2005-07-27 10:11:09 bkorb"
  *
- *  autoopts.h  $Id: autoopts.h,v 2.50 2004/10/02 21:37:46 bkorb Exp $
+ *  autoopts.h  $Id: autoopts.h,v 4.12 2005/07/27 17:26:32 bkorb Exp $
+ *  Time-stamp:      "2005-02-14 05:59:50 bkorb"
  *
  *  This file defines all the global structures and special values
  *  used in the automated option processing library.
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -24,8 +25,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -54,7 +55,9 @@
 #ifndef AUTOGEN_AUTOOPTS_H
 #define AUTOGEN_AUTOOPTS_H
 
-#define __EXTENSIONS__
+#ifndef   __EXTENSIONS__
+#  define __EXTENSIONS__
+#endif
 
 #include "config.h"
 #include "compat/compat.h"
@@ -65,9 +68,20 @@
 
 #define AO_NAME_LIMIT    127
 #define AO_NAME_SIZE     (AO_NAME_LIMIT + 1)
+
 #ifndef MAXPATHLEN
-#  define MAXPATHLEN     4096
+#  ifdef PATH_MAX
+#    define MAXPATHLEN   PATH_MAX
+#  else
+#    define MAXPATHLEN   4096
+#  endif
+#else
+#  if defined(PATH_MAX) && (PATH_MAX > MAXPATHLEN)
+#     undef  MAXPATHLEN
+#     define MAXPATHLEN  PATH_MAX
+#  endif
 #endif
+
 #undef  EXPORT
 #define EXPORT
 
@@ -84,9 +98,13 @@
 typedef int tDirection;
 #define DIRECTION_PRESET  -1
 #define DIRECTION_PROCESS  1
+#define DIRECTION_CALLED   0
+
 #define PROCESSING(d)     ((d)>0)
 #define PRESETTING(d)     ((d)<0)
 
+#define ISNAMECHAR( c )    (isalnum(c) || ((c) == '_') || ((c) == '-'))
+
 /*
  *  Procedure success codes
  *
@@ -105,11 +123,11 @@ typedef int tSuccess;
 #define HADGLITCH( p )     ((p) >  SUCCESS)
 
 /*
- *  The pager state is used by doPagedUsage() procedure.
+ *  The pager state is used by optionPagedUsage() procedure.
  *  When it runs, it sets itself up to be called again on exit.
  *  If, however, a routine needs a child process to do some work
  *  before it is done, then 'pagerState' must be set to
- *  'PAGER_STATE_CHILD' so that doPagedUsage() will not try
+ *  'PAGER_STATE_CHILD' so that optionPagedUsage() will not try
  *  to run the pager program before its time.
  */
 typedef enum {
@@ -135,13 +153,12 @@ typedef enum {
 
 typedef struct {
     tOptDesc*  pOD;
+    tCC*       pzOptArg;
     tUL        flags;
     teOptType  optType;
-    int        argType;
-    tCC*       pzOptArg;
 } tOptState;
-#define OPTSTATE_INITIALIZER \
-    { NULL, OPTST_DEFINED, TOPT_UNDEFINED, 0, NULL }
+#define OPTSTATE_INITIALIZER(st) \
+    { NULL, NULL, OPTST_ ## st, TOPT_UNDEFINED }
 
 #define TEXTTO_TABLE \
         _TT_( LONGUSAGE ) \
@@ -161,6 +178,7 @@ typedef struct {
     tCC*    pzKey;
     tCC*    pzKeyL;
     tCC*    pzBool;
+    tCC*    pzNest;
     tCC*    pzOpt;
     tCC*    pzNo;
     tCC*    pzBrk;
@@ -253,64 +271,74 @@ typedef struct {
     || (((_flg) & (OPTST_DISABLED|OPTST_DISABLE_TWICE))  ==     \
                   (OPTST_DISABLED|OPTST_DISABLE_TWICE)  ))
 
+/*
+ *  text_mmap structure.  Only active on platforms with mmap(2).
+ */
+#ifdef HAVE_SYS_MMAN_H
+#  include <sys/mman.h>
+#else
+#  ifndef  PROT_READ
+#   define PROT_READ    0x01
+#  endif
+#  ifndef  PROT_WRITE
+#   define PROT_WRITE   0x02
+#  endif
+#  ifndef  MAP_SHARED
+#   define MAP_SHARED   0x01
+#  endif
+#  ifndef  MAP_PRIVATE
+#   define MAP_PRIVATE  0x02
+#  endif
+#endif
+
+#ifndef MAP_FAILED
+#  define  MAP_FAILED   ((void*)-1)
+#endif
+
+#ifndef  _SC_PAGESIZE
+# ifdef  _SC_PAGE_SIZE
+#  define _SC_PAGESIZE _SC_PAGE_SIZE
+# endif
+#endif
+
+/*
+ *  This is an output only structure used by text_mmap and text_munmap.
+ *  Clients must not alter the contents and must provide it to both
+ *  the text_mmap and text_munmap procedures.  BE ADVISED: if you are
+ *  mapping the file with PROT_WRITE the NUL byte at the end MIGHT NOT
+ *  BE WRITABLE.  In any event, that byte is not be written back
+ *  to the source file.  ALSO: if "txt_data" is valid and "txt_errno"
+ *  is not zero, then there *may* not be a terminating NUL.
+ */
+typedef struct {
+    void*       txt_data;      /* text file data   */
+    size_t      txt_size;      /* actual file size */
+    int         txt_fd;        /* file descriptor  */
+    size_t      txt_full_size; /* mmaped mem size  */
+    int         txt_zero_fd;   /* fd for /dev/zero */
+    int         txt_errno;     /* warning code     */
+    int         txt_prot;      /* "prot" flags     */
+    int         txt_flags;     /* mapping type     */
+} tmap_info_t;
+
 /*
  *  Define and initialize all the user visible strings.
  *  We do not do translations.  If translations are to be done, then
  *  the client will provide a callback for that purpose.
  */
 #undef DO_TRANSLATIONS
-#include "usage-txt.h"
+#include "autoopts/usage-txt.h"
 
 /*
  *  File pointer for usage output
  */
 extern FILE* option_usage_fp;
 
-extern tOptProc doVersion, doPagedUsage, doLoadOpt;
+extern tOptProc optionPrintVersion, optionPagedUsage, optionLoadOpt;
 
 #define LOCAL static
-#ifdef AUTOOPTS_INTERNAL
-/* === LOCAL PROCEDURES === */
+#include "proto.h"
 
-/* autoopts.c */
-static tSuccess
-handleOption( tOptions* pOpts, tOptState* pOptState );
-
-static tSuccess
-longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
-
-static tSuccess
-shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );
-
-static tSuccess
-doImmediateOpts( tOptions* pOpts );
-
-static tSuccess
-doRegularOpts( tOptions* pOpts );
-
-
-/* environment.c */
-static void
-doPrognameEnv( tOptions* pOpts, teEnvPresetType type );
-
-static void
-doEnvPresets( tOptions* pOpts, teEnvPresetType type );
-
-
-/* load.c */
-static void
-filePreset(
-    tOptions*     pOpts,
-    const char*   pzFileName,
-    int           direction );
-
-
-/* sort.c */
-static void
-optionSort( tOptions* pOpts );
-
-/* === END LOCALS === */
-#endif /* GUILE_OPTIONS */
 #endif /* AUTOGEN_AUTOOPTS_H */
 /*
  * Local Variables:
