@@ -1,6 +1,6 @@
 /*
- *  $Id: configfile.c,v 4.8 2005/06/07 22:26:44 bkorb Exp $
- *  Time-stamp:      "2005-04-03 15:53:54 bkorb"
+ *  $Id: configfile.c,v 4.10 2005/07/27 17:26:32 bkorb Exp $
+ *  Time-stamp:      "2005-07-27 10:09:29 bkorb"
  *
  *  configuration/rc/ini file handling.
  */
@@ -152,7 +152,7 @@ configFileLoad( const char* pzFile )
         return NULL; /* errno is set */
 
     pRes = optionLoadNested(pzText, pzFile, strlen(pzFile), OPTION_LOAD_COOKED);
- all_done:
+
     if (pRes == NULL) {
         int err = errno;
         text_munmap( &cfgfile );
@@ -442,7 +442,6 @@ filePreset(
     tmap_info_t   cfgfile;
     char*         pzFileText =
         text_mmap( pzFileName, PROT_READ|PROT_WRITE, MAP_PRIVATE, &cfgfile );
-    char*         pzEndText;
     tOptState     st = OPTSTATE_INITIALIZER(PRESET);
 
     if (pzFileText == MAP_FAILED)
@@ -462,8 +461,6 @@ filePreset(
     if ((pOpts->fOptSet & OPTPROC_PRESETTING) == 0)
         st.flags = OPTST_SET;
 
-    pzEndText = pzFileText + cfgfile.txt_size;
-
     do  {
         while (isspace( *pzFileText ))  pzFileText++;
 
@@ -706,7 +703,6 @@ handleStructure(
 
     char* pzName = ++pzText;
     char* pcNulPoint;
-    char* pzValStart;
 
     while (ISNAMECHAR( *pzText ))  pzText++;
     pcNulPoint = pzText;
@@ -738,7 +734,6 @@ handleStructure(
             pzText++;
         return pzText;
     }
-    pzValStart = ++pzText;
 
     /*
      *  If we are here, we have a value.  Separate the name from the
@@ -794,7 +789,7 @@ internalFileLoad( tOptions* pOpts )
 {
     int     idx;
     int     inc = DIRECTION_PRESET;
-    char    zFileName[ 4096 ];
+    char    zFileName[ MAXPATHLEN+1 ];
 
     if (pOpts->papzHomeList == NULL)
         return;
