@@ -1,12 +1,13 @@
 
 /*
- *  sort.c  $Id: sort.c,v 4.1 2005/01/01 00:12:42 bkorb Exp $
+ *  sort.c  $Id: sort.c,v 4.6 2005/06/07 22:26:44 bkorb Exp $
+ * Time-stamp:      "2005-02-20 17:18:41 bkorb"
  *
  *  This module implements argument sorting.
  */
 
 /*
- *  Automated Options copyright 1992-2004 Bruce Korb
+ *  Automated Options copyright 1992-2005 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,8 +22,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Automated Options.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  *
  * As a special exception, Bruce Korb gives permission for additional
  * uses of the text contained in his release of AutoOpts.
@@ -48,15 +49,27 @@
  * If you do not wish that, delete this exception notice.
  */
 
-/* === STATIC PROCS === */
-/* === END STATIC PROCS === */
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tSuccess
+mustHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
+               char** ppzOpts, int* pOptsIdx );
+
+static tSuccess
+mayHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
+              char** ppzOpts, int* pOptsIdx );
+
+static tSuccess
+checkShortOpts( tOptions* pOpts, char* pzArg, tOptState* pOS,
+                char** ppzOpts, int* pOptsIdx );
+/* = = = END-STATIC-FORWARD = = = */
 
 /*
  *  "mustHandleArg" and "mayHandleArg" are really similar.  The biggest
  *  difference is that "may" will consume the next argument only if it
  *  does not start with a hyphen and "must" will consume it, hyphen or not.
  */
-STATIC tSuccess
+static tSuccess
 mustHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
                char** ppzOpts, int* pOptsIdx )
 {
@@ -94,7 +107,7 @@ mustHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
     return SUCCESS;
 }
 
-STATIC tSuccess
+static tSuccess
 mayHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
               char** ppzOpts, int* pOptsIdx )
 {
@@ -137,7 +150,7 @@ mayHandleArg( tOptions* pOpts, char* pzArg, tOptState* pOS,
  *  Process a string of short options glued together.  If the last one
  *  does or may take an argument, the do the argument processing and leave.
  */
-STATIC tSuccess
+static tSuccess
 checkShortOpts( tOptions* pOpts, char* pzArg, tOptState* pOS,
                 char** ppzOpts, int* pOptsIdx )
 {
@@ -145,21 +158,13 @@ checkShortOpts( tOptions* pOpts, char* pzArg, tOptState* pOS,
         if (FAILED( shortOptionFind( pOpts, *pzArg, pOS )))
             return FAILURE;
 
-        switch (pOS->pOD->optArgType) {
-        case ARG_MUST:
-            /*
-             *  IF we need another argument, be sure it is there and
-             *  take it.
-             */
-            if (pzArg[1] == NUL) {
-                if (pOpts->curOptIdx >= pOpts->origArgCt)
-                    return FAILURE;
-                ppzOpts[ (*pOptsIdx)++ ] =
-                    pOpts->origArgVect[ (pOpts->curOptIdx)++ ];
-            }
-            return SUCCESS;
+        /*
+         *  See if we can have an arg.
+         */
+        if (OPTST_GET_ARGTYPE(pOS->pOD->fOptState) == OPARG_TYPE_NONE) {
+            pzArg++;
 
-        case ARG_MAY:
+        } else if (pOS->pOD->fOptState & OPTST_ARG_OPTIONAL) {
             /*
              *  Take an argument if it is not attached and it does not
              *  start with a hyphen.
@@ -173,8 +178,18 @@ checkShortOpts( tOptions* pOpts, char* pzArg, tOptState* pOS,
                     pOpts->origArgVect[ (pOpts->curOptIdx)++ ];
             return SUCCESS;
 
-        default:
-            pzArg++;
+        } else {
+            /*
+             *  IF we need another argument, be sure it is there and
+             *  take it.
+             */
+            if (pzArg[1] == NUL) {
+                if (pOpts->curOptIdx >= pOpts->origArgCt)
+                    return FAILURE;
+                ppzOpts[ (*pOptsIdx)++ ] =
+                    pOpts->origArgVect[ (pOpts->curOptIdx)++ ];
+            }
+            return SUCCESS;
         }
     }
     return SUCCESS;
@@ -192,7 +207,7 @@ optionSort( tOptions* pOpts )
     int    optsIdx = 0;
     int    opdsIdx = 0;
 
-    tOptState os = { NULL, OPTST_DEFINED, TOPT_UNDEFINED, 0, NULL };
+    tOptState os = OPTSTATE_INITIALIZER(DEFINED);
 
     /*
      *  Disable for POSIX conformance
@@ -296,22 +311,7 @@ optionSort( tOptions* pOpts )
          */
         ppzOpts[ optsIdx++ ] = pOpts->origArgVect[ (pOpts->curOptIdx)++ ];
 
-        switch (os.pOD->optArgType) {
-        case ARG_MUST:
-            switch (mustHandleArg( pOpts, pzArg+2, &os, ppzOpts, &optsIdx )) {
-            case PROBLEM:
-            case FAILURE: errno = EIO; goto freeTemps;
-            }
-            goto nextArg;
-
-        case ARG_MAY:
-            switch (mayHandleArg( pOpts, pzArg+2, &os, ppzOpts, &optsIdx )) {
-            case FAILURE: errno = EIO; goto freeTemps;
-            case PROBLEM: errno = 0;   goto joinLists;
-            }
-            goto nextArg;
-
-        default: /* CANNOT */
+        if (OPTST_GET_ARGTYPE(os.pOD->fOptState) == OPARG_TYPE_NONE) {
             /*
              *  No option argument.  If we have a short option here,
              *  then scan for short options until we get to the end
@@ -323,7 +323,19 @@ optionSort( tOptions* pOpts )
                 errno = EIO;
                 goto freeTemps;
             }
-        } nextArg:;
+
+        } else if (os.pOD->fOptState & OPTST_ARG_OPTIONAL) {
+            switch (mayHandleArg( pOpts, pzArg+2, &os, ppzOpts, &optsIdx )) {
+            case FAILURE: errno = EIO; goto freeTemps;
+            case PROBLEM: errno = 0;   goto joinLists;
+            }
+
+        } else {
+            switch (mustHandleArg( pOpts, pzArg+2, &os, ppzOpts, &optsIdx )) {
+            case PROBLEM:
+            case FAILURE: errno = EIO; goto freeTemps;
+            }
+        }
     } /* for (;;) */
 
  restOperands:
@@ -354,4 +366,4 @@ optionSort( tOptions* pOpts )
  * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * end of autoopts/usage.c */
+ * end of autoopts/sort.c */
