@@ -2,16 +2,20 @@
 
 /* --- fake the preprocessor into handlng portability */
 /*
- *  Time-stamp:      "2004-10-14 18:35:54 bkorb"
+ *  Time-stamp:      "2005-06-26 08:18:00 bkorb"
  *
  * Author:           Gary V Vaughan <gvaughan@oranda.demon.co.uk>
  * Created:          Mon Jun 30 15:54:46 1997
  *
- * $Id: compat.h,v 2.20 2004/10/15 01:54:16 bkorb Exp $
+ * $Id: compat.h,v 4.4 2005/06/26 16:26:45 bkorb Exp $
  */
 #ifndef COMPAT_H
 #define COMPAT_H 1
 
+#ifndef HAVE_CONFIG_H
+#  error "compat.h" requires "config.h"
+#endif
+
 #include <config.h>
 
 #ifndef HAVE_STRSIGNAL
@@ -104,11 +108,6 @@
 #   if defined (HAVE_NDIR_H)
 #     include <ndir.h>
 #   endif /* HAVE_NDIR_H */
-#   if !defined (HAVE_SYS_NDIR_H) && \
-       !defined (HAVE_SYS_DIR_H)  && \
-       !defined (HAVE_NDIR_H)
-#     include "ndir.h"
-#   endif /* !HAVE_SYS_NDIR_H && !HAVE_SYS_DIR_H && !HAVE_NDIR_H */
 # endif /* !HAVE_DIRENT_H */
 
 #include <errno.h>
@@ -122,11 +121,8 @@
 #if defined(HAVE_LIBGEN) && defined(HAVE_LIBGEN_H)
 #  include <libgen.h>
 #endif
-#ifdef HAVE_LIMITS_H
-#  include <limits.h>
-#else
-#  include <sys/limits.h>
-#endif
+
+#include <limits.h>
 #include <memory.h>
 #include <setjmp.h>
 #include <signal.h>
@@ -144,7 +140,7 @@
 #include <utime.h>
 
 #ifdef HAVE_UNISTD_H
-#   include <unistd.h>
+#  include <unistd.h>
 #endif
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -157,14 +153,6 @@
 #   define EXTERN extern
 #endif
 
-#undef STATIC
-
-#ifdef DEBUG
-#  define STATIC
-#else
-#  define STATIC static
-#endif
-
 /* some systems #def errno! and others do not declare it!! */
 #ifndef errno
    extern int errno;
@@ -215,11 +203,6 @@
 #  define strrchr       rindex
 #endif
 
-#ifndef HAVE_PATHFIND
-#  define  pathfind  option_pathfind
-   EXTERN char *pathfind(const char *, const char *, const char *);
-#endif
-
 #ifdef USE_FOPEN_BINARY
 #  ifndef FOPEN_BINARY_FLAG
 #    define FOPEN_BINARY_FLAG   "b"
@@ -255,6 +238,7 @@
 #endif
 
 #endif /* COMPAT_H */
+
 /*
  * Local Variables:
  * mode: C
@@ -262,4 +246,4 @@
  * tab-width: 4
  * indent-tabs-mode: nil
  * End:
- * compat.h ends here */
+ * end of compat/compat.h */
