@@ -874,9 +874,8 @@ printf_integer (STREAM *stream, struct printf_info *const pinfo, union printf_ar
     }
   else
     {
-      intmax_t svalue = 0L;
-      svalue = fetch_intmax (pinfo, args);
-      is_negative = (svalue < 0);
+      intmax_t svalue = fetch_intmax (pinfo, args);
+      is_negative = (svalue < 0) ? SNV_TRUE : SNV_FALSE;
       value = (uintmax_t) ABS (svalue);
     }
 
